@@ -32,7 +32,9 @@ Example:
     >>> df_processed = df[[col for col in df.columns if col != 'date']]
     >>> 
     >>> # Step 2: Create Dataset
-    >>> dataset = DFMDataset(config_path='config/default.yaml', data=df_processed)
+    >>> from dfm_python.config import DFMConfig
+    >>> config = DFMConfig.from_yaml('config/default.yaml')
+    >>> dataset = DFMDataset(config=config, data=df_processed)
     >>> 
     >>> # Step 3: Create model and load config
     >>> model = DFM()
@@ -61,7 +63,7 @@ Note: DFMConfig uses frequency dict to specify series (column names -> frequenci
 For detailed documentation, see the README.md file and the tutorial notebooks/scripts.
 """
 
-__version__ = "0.5.56"
+__version__ = "0.5.60"
 
 # ============================================================================
 # PUBLIC API DEFINITION
@@ -102,7 +104,10 @@ from .models.base import BaseFactorModel
 from .models.dfm import DFM
 
 # DDFM high-level API (PyTorch is mandatory)
-from .models.ddfm import DDFM
+try:
+    from .models.ddfm.ddfm import DDFM
+except ImportError:
+    DDFM = None
 
 __all__ = [
     # Core classes
