@@ -303,7 +303,6 @@ class YamlSource:
         _EXCLUDED_KEYS = {
             'defaults', '_target_', '_recursive_', '_convert_', 
             'series', 'blocks', 'data', 'output', 'description', 'name', 'target', 'model',
-            'nan_method', 'nan_k'  # Internal constants, not user-configurable
         }
         main_settings = {k: v for k, v in cfg_dict.items() if k not in _EXCLUDED_KEYS}
         
@@ -552,6 +551,11 @@ def detect_config_type(data: Dict[str, Any]) -> str:
     if model_type == MODEL_TYPE_DFM:
         return MODEL_TYPE_DFM
     
+    # Priority check: blocks parameter indicates DFM (highest priority)
+    # DFM is the only model type that uses blocks structure
+    if 'blocks' in data and data.get('blocks'):
+        return MODEL_TYPE_DFM
+    
     # Check for model-specific parameters
     keys = set(data.keys())
     if keys & _KDFM_PARAMS:
