@@ -7,17 +7,21 @@ This package contains implementations of different factor models:
 
 from .base import BaseFactorModel
 from .dfm import DFM
-from ..config import BaseResult, DFMResult, DDFMResult, FitParams
+from ..config import BaseResult, DFMResult, DDFMResult
 
 __all__ = [
     'BaseFactorModel', 'DFM',
     # Results
-    'BaseResult', 'DFMResult', 'DDFMResult', 'FitParams',
+    'BaseResult', 'DFMResult', 'DDFMResult',
 ]
 
 # DDFM implementation
-from .ddfm import DDFM
-__all__.extend([
-    'DDFM',  # High-level API
-])
+try:
+    from .ddfm.ddfm import DDFM
+    __all__.extend([
+        'DDFM',  # High-level API
+    ])
+except ImportError:
+    # DDFM not available (missing torch or other dependencies)
+    pass
 
